import React, { useState, useEffect } from 'react'
import ReactDOM from 'react-dom/client'
import { supabase } from './lib/supabase'

// Simple test component with Supabase integration
function App() {
  const [connectionStatus, setConnectionStatus] = useState('Testing...')
  const [error, setError] = useState(null)
  const [user, setUser] = useState(null)
  
  useEffect(() => {
    // Test Supabase connection
    async function testConnection() {
      try {
        // Simple health check
        const { data, error } = await supabase.from('_anon_key_health_check').select('*').limit(1)
        
        if (error) {
          console.error('Supabase connection error:', error)
          setConnectionStatus('Failed to connect to Supabase')
          setError(error.message)
        } else {
          console.log('Supabase connection successful:', data)
          setConnectionStatus('Successfully connected to Supabase!')
        }
        
        // Check if user is authenticated
        const { data: { user } } = await supabase.auth.getUser()
        setUser(user)
      } catch (err) {
        console.error('Error testing connection:', err)
        setConnectionStatus('Error testing connection')
        setError(err.message)
      }
    }
    
    testConnection()
  }, [])
  
  return (
    <div style={{ padding: '20px', fontFamily: 'Arial, sans-serif', maxWidth: '800px', margin: '0 auto' }}>
      <h1 style={{ color: '#4285f4' }}>Supabase Connection Test</h1>
      <p>If you can see this, React is working correctly!</p>
      
      <div style={{ marginTop: '20px', padding: '15px', backgroundColor: connectionStatus.includes('Success') ? '#e6f7e6' : '#ffebee', borderRadius: '4px' }}>
        <h3>Supabase Connection Status:</h3>
        <p><strong>{connectionStatus}</strong></p>
        {error && <p style={{ color: 'red' }}>Error: {error}</p>}
      </div>
      
      <div style={{ marginTop: '20px', padding: '15px', backgroundColor: '#f5f5f5', borderRadius: '4px' }}>
        <h3>Authentication Status:</h3>
        {user ? (
          <div>
            <p>Logged in as: {user.email}</p>
            <button 
              style={{
                backgroundColor: '#f44336',
                border: 'none',
                color: 'white',
                padding: '10px 20px',
                textAlign: 'center',
                fontSize: '16px',
                margin: '10px 2px',
                cursor: 'pointer',
                borderRadius: '4px'
              }}
              onClick={async () => {
                await supabase.auth.signOut()
                window.location.reload()
              }}
            >
              Sign Out
            </button>
          </div>
        ) : (
          <p>Not logged in</p>
        )}
      </div>
      
      <button 
        style={{
          backgroundColor: '#4CAF50',
          border: 'none',
          color: 'white',
          padding: '10px 20px',
          textAlign: 'center',
          fontSize: '16px',
          margin: '20px 2px',
          cursor: 'pointer',
          borderRadius: '4px'
        }}
        onClick={() => window.location.reload()}
      >
        Refresh Test
      </button>
    </div>
  )
}

ReactDOM.createRoot(document.getElementById('root')).render(
  <React.StrictMode>
    <App />
  </React.StrictMode>,
)
